@@ -3,29 +3,33 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
+ 'ASDLGEN': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl_c.py',
+ 'ASDLGEN_FILES': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl.py /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl_c.py',
+ 'AST_ASDL': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/Python.asdl',
+ 'AST_C': 'Python/Python-ast.c',
+ 'AST_C_DIR': 'Python',
+ 'AST_H': 'Include/Python-ast.h',
+ 'AST_H_DIR': 'Include',
  'ATHEOS_THREADS': 0,
  'BASECFLAGS': '-fno-strict-aliasing',
  'BASEMODLIBS': '',
  'BEOS_THREADS': 0,
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python2.7',
- 'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared',
- 'BUILDEXE': '',
- 'BUILDPYTHON': 'python',
+ 'BLDLIBRARY': 'libpython2.7.dll.a',
+ 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -L.',
+ 'BUILDEXE': '.exe',
+ 'BUILDPYTHON': 'python.exe',
  'CC': 'gcc',
- 'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -g -O2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
- 'CFLAGSFORSHARED': '-fPIC',
+ 'CCSHARED': '',
+ 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-system-expat' '--with-system-ffi' '--with-ensurepip=yes' '--enable-optimizations' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--enable-unicode=ucs4' '--with-dbmliborder=bdb:gdbm:ndbm'",
+ 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python' '--htmldir=/usr/share/doc/python/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
- 'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18/coverage.info',
- 'COVERAGE_REPORT': '/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include',
+ 'COREPYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
+ 'CPPFLAGS': '-I. -IInclude -I/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Include  -I/usr/include/ncursesw',
  'CXX': 'g++',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
@@ -37,14 +41,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
  'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
- 'DLLLIBRARY': '',
+ 'DLLLIBRARY': 'libpython2.7.dll',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'upgrade',
- 'EXE': '',
+ 'ENSUREPIP': 'no',
+ 'EXE': '.exe',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
  'EXTRAPLATDIR': '',
@@ -54,11 +58,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
- 'GITBRANCH': '',
- 'GITTAG': '',
- 'GITVERSION': '',
  'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
+ 'GRAMMAR_C': 'Python/graminit.c',
+ 'GRAMMAR_H': 'Include/graminit.h',
+ 'GRAMMAR_INPUT': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -71,11 +75,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
- 'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
+ 'HAVE_BROKEN_PTHREAD_SIGMASK': 1,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_C99_BOOL': 1,
@@ -83,25 +87,15 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
- 'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
- 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
- 'HAVE_CURSES_HAS_KEY': 1,
- 'HAVE_CURSES_IMMEDOK': 1,
- 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
- 'HAVE_CURSES_SYNCOK': 1,
- 'HAVE_CURSES_TYPEAHEAD': 1,
- 'HAVE_CURSES_USE_ENV': 1,
- 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -115,7 +109,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DYNAMIC_LOADING': 1,
- 'HAVE_EPOLL': 1,
+ 'HAVE_EPOLL': 0,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
@@ -145,15 +139,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 1,
  'HAVE_GETGROUPS': 1,
- 'HAVE_GETHOSTBYNAME': 0,
- 'HAVE_GETHOSTBYNAME_R': 1,
+ 'HAVE_GETHOSTBYNAME': 1,
+ 'HAVE_GETHOSTBYNAME_R': 0,
  'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
- 'HAVE_GETHOSTBYNAME_R_6_ARG': 1,
+ 'HAVE_GETHOSTBYNAME_R_6_ARG': 0,
  'HAVE_GETITIMER': 1,
- 'HAVE_GETLOADAVG': 1,
+ 'HAVE_GETLOADAVG': 0,
  'HAVE_GETLOGIN': 1,
  'HAVE_GETNAMEINFO': 1,
  'HAVE_GETPAGESIZE': 1,
@@ -163,31 +156,31 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
- 'HAVE_GETRESGID': 1,
- 'HAVE_GETRESUID': 1,
+ 'HAVE_GETRESGID': 0,
+ 'HAVE_GETRESUID': 0,
  'HAVE_GETSID': 1,
- 'HAVE_GETSPENT': 1,
- 'HAVE_GETSPNAM': 1,
+ 'HAVE_GETSPENT': 0,
+ 'HAVE_GETSPNAM': 0,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HYPOT': 1,
- 'HAVE_IEEEFP_H': 0,
+ 'HAVE_IEEEFP_H': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
  'HAVE_INT32_T': 1,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
- 'HAVE_IO_H': 0,
+ 'HAVE_IO_H': 1,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
  'HAVE_LANGINFO_H': 1,
  'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
- 'HAVE_LCHMOD': 1,
+ 'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 1,
@@ -198,8 +191,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
- 'HAVE_LINUX_NETLINK_H': 1,
- 'HAVE_LINUX_TIPC_H': 1,
+ 'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LOG1P': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
@@ -211,10 +204,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_MKNOD': 1,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
- 'HAVE_MREMAP': 1,
+ 'HAVE_MREMAP': 0,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
- 'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NICE': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
@@ -223,7 +216,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
- 'HAVE_PROCESS_H': 0,
+ 'HAVE_PROCESS_H': 1,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -242,7 +235,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
- 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
@@ -258,13 +250,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
  'HAVE_SETREGID': 1,
- 'HAVE_SETRESGID': 1,
- 'HAVE_SETRESUID': 1,
+ 'HAVE_SETRESGID': 0,
+ 'HAVE_SETRESUID': 0,
  'HAVE_SETREUID': 1,
  'HAVE_SETSID': 1,
  'HAVE_SETUID': 1,
  'HAVE_SETVBUF': 1,
- 'HAVE_SHADOW_H': 1,
+ 'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
@@ -286,37 +278,36 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
  'HAVE_STROPTS_H': 0,
- 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
+ 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
  'HAVE_STRUCT_STAT_ST_FLAGS': 0,
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
+ 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DIR_H': 0,
- 'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_LOADAVG_H': 0,
- 'HAVE_SYS_LOCK_H': 0,
+ 'HAVE_SYS_LOCK_H': 1,
  'HAVE_SYS_MKDEV_H': 0,
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
- 'HAVE_SYS_SYSMACROS_H': 1,
- 'HAVE_SYS_TERMIO_H': 0,
+ 'HAVE_SYS_TERMIO_H': 1,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
@@ -334,7 +325,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
  'HAVE_TMPNAM': 1,
- 'HAVE_TMPNAM_R': 1,
+ 'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
  'HAVE_TZNAME': 0,
@@ -345,7 +336,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNSETENV': 1,
- 'HAVE_USABLE_WCHAR_T': 0,
+ 'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
@@ -357,7 +348,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
+ 'HGBRANCH': 'hg id -b /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'HGTAG': 'hg id -t /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'HGVERSION': 'hg id -i /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'HOST_GNU_TYPE': 'x86_64-unknown-cygwin',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
  'INCLUDEDIR': '/usr/include',
@@ -367,18 +361,18 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython2.7.so.1.0',
- 'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '',
+ 'INSTSONAME': 'libpython2.7.dll.a',
+ 'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
+ 'LDFLAGS': '-L.',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython2.7.so',
+ 'LDLIBRARY': 'libpython2.7.dll.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared',
+ 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -L.',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
- 'LIBM': '-lm',
+ 'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBP': '/usr/lib/python2.7',
@@ -389,23 +383,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'gcc',
- 'LINKFORSHARED': '-Xlinker -export-dynamic',
- 'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': '',
- 'LLVM_PROF_MERGER': 'true',
- 'LN': 'ln',
+ 'LINKFORSHARED': '',
+ 'LN': 'ln -s',
  'LOCALMODLIBS': '',
- 'MACHDEP': 'linux2',
- 'MACHDEPPATH': ':plat-linux2',
- 'MACHDEPS': 'plat-linux2',
+ 'MACHDEP': 'cygwin',
+ 'MACHDEPPATH': ':plat-cygwin',
+ 'MACHDEPS': 'plat-cygwin',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python2.7',
  'MACH_C_THREADS': 0,
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': './Modules/makesetup',
+ 'MAJOR_IN_SYSMACROS': 0,
+ 'MAKESETUP': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -426,58 +417,55 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
  'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
- 'PGEN': 'Parser/pgen',
+ 'PGEN': 'Parser/pgen.exe',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-linux2',
+ 'PLATDIR': 'plat-cygwin',
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
+ 'PROFILE_TASK': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
- 'PYTHON': 'python',
+ 'PYTHON': 'python.exe',
  'PYTHONFRAMEWORK': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
+ 'PYTHON_FOR_BUILD': './python.exe -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -g -O2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I./Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Include  -I/usr/include/ncursesw  -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 0,
+ 'PY_UNICODE_TYPE': 'wchar_t',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 4,
+ 'Py_UNICODE_SIZE': 2,
  'Py_USING_UNICODE': 1,
  'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18',
+ 'RUNSHARED': '',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
  'SHLIBS': '-ldl',
- 'SHLIB_EXT': '".so"',
+ 'SHLIB_EXT': '".dll"',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
  'SIZEOF_FLOAT': 4,
- 'SIZEOF_FPOS_T': 16,
+ 'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 8,
  'SIZEOF_LONG_DOUBLE': 16,
@@ -490,25 +478,26 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_TIME_T': 8,
  'SIZEOF_UINTPTR_T': 8,
  'SIZEOF_VOID_P': 8,
- 'SIZEOF_WCHAR_T': 4,
+ 'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
- 'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'SO': '.dll',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SRC_GDB_HOOKS': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SYSLIBS': '-lm',
+ 'SVNVERSION': 'svnversion /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18 ./python -Wd -3 -E -tt',
+ 'TESTPROG': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Lib/test/regrtest.py',
+ 'TESTPYTHON': './python.exe -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -516,16 +505,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
  'UNIVERSALSDK': '',
- 'USE_COMPUTED_GOTOS': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
- 'VA_LIST_IS_ARRAY': 1,
+ 'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
+ 'VPATH': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
- 'WITH_LIBINTL': 0,
+ 'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_THREAD': 1,
@@ -533,11 +522,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18',
- 'abs_srcdir': '/home/evie/packages/python2/python2-2.7.18-0/Python-2.7.18',
- 'build': 'x86_64-pc-linux-gnu',
+ 'abs_builddir': '/usr/src/ports/python/python-2.7.9-1.x86_64/build',
+ 'abs_srcdir': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'build': 'x86_64-unknown-cygwin',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'x86_64-pc-linux-gnu',
+ 'host': 'x86_64-unknown-cygwin',
  'prefix': '/usr',
- 'srcdir': '.'}
+ 'srcdir': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9'}
